package com.digiwin.athena.app.chatFile.service.chatFile;

import com.alibaba.fastjson.TypeReference;
import com.alibaba.nacos.common.utils.StringUtils;
import com.digiwin.app.container.exceptions.DWBusinessException;
import com.digiwin.app.service.DWEAIResult;
import com.digiwin.athena.app.chatFile.infra.entity.ChatFileEntity;
import com.digiwin.athena.app.chatFile.infra.service.ChatFileService;
import com.digiwin.athena.opt.common.eai.EAIRequest;
import com.digiwin.athena.opt.common.eai.service.AbsEAIService;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @auther: zhenggl
 * @date: 2023/9/7
 */
@Service
@Log4j2
public class ChatFileCreateEAIService extends AbsEAIService {

    @Resource
    private ChatFileService chatFileService;

    @Override
    public String getServiceName() {
        return ChatFileUtil.CA_CHAT_FILE_INFO_CREATE;
    }

    @Override
    public DWEAIResult execute(Map<String, String> headers, String messageBody) throws Exception {
        EAIRequest eaiRequest = EAIRequest.build(messageBody);
        List<ChatFileEntity> chatFileInfo = eaiRequest.getObject("chat_file_info", new TypeReference<List<ChatFileEntity>>(){});

        Date date = new Date();
        for (ChatFileEntity chatFileEntity : chatFileInfo) {
            if (StringUtils.isEmpty(chatFileEntity.getQuestion())){
                throw new DWBusinessException("问题描述不能为空");
            }
            //反馈时间
            chatFileEntity.setFeedbackDate(date);
        }


        chatFileService.saveBatch(chatFileInfo);

        return buildOK("chat_file_info",chatFileInfo);
    }
}
